.. This README is auto-generated from `docs/README.md`. Do not edit this file directly.

===========================================================
yaml2cli — Script Generator that organizes cli args by YAML
===========================================================

:Date:   October 12, 2018

.. contents::
   :depth: 3
..

|Build Status| |GitHub Releases| |PyPI version| |Development Status|
|Python version| |License| |Coveralls|

Organize cli args through YAML. Useful for organizing huge amounts of
cli args, as well as a tons of commands with interelated cli args.
Useful for a long pipeline with dependencies with each other.

To see what it does, run ``make examples`` and see the script generated
from ``examples/example.sh`` and ``examples/example.yml``.

.. |Build Status| image:: https://travis-ci.org/ickc/yaml2cli.svg?branch=master
   :target: https://travis-ci.org/ickc/yaml2cli
.. |GitHub Releases| image:: https://img.shields.io/github/tag/ickc/yaml2cli.svg?label=github+release
   :target: https://github.com/ickc/yaml2cli/releases
.. |PyPI version| image:: https://img.shields.io/pypi/v/yaml2cli.svg
   :target: https://pypi.python.org/pypi/yaml2cli/
.. |Development Status| image:: https://img.shields.io/pypi/status/yaml2cli.svg
   :target: https://pypi.python.org/pypi/yaml2cli/
.. |Python version| image:: https://img.shields.io/pypi/pyversions/yaml2cli.svg
   :target: https://pypi.python.org/pypi/yaml2cli/
.. |License| image:: https://img.shields.io/pypi/l/yaml2cli.svg
.. |Coveralls| image:: https://img.shields.io/coveralls/ickc/yaml2cli.svg
   :target: https://coveralls.io/github/ickc/yaml2cli
